==> fluxbb-1.4.2p0.tgz: fluxbb/lang/English/post.php <==
<?php

// Language definitions used in post.php and edit.php
$lang_post = array(

// Post validation stuff (many are similiar to those in edit.php)
'No subject'		=>	'Topics must contain a subject.',
'Too long subject'	=>	'Subjects cannot be longer than 70 characters.',
'No message'		=>	'You must enter a message.',
'Too long message'	=>	'Posts cannot be longer that %s bytes.',
'All caps subject'	=>	'Subjects cannot contain only capital letters.',
'All caps message'	=>	'Posts cannot contain only capital letters.',

// Posting
'Post errors'		=>	'Post errors',
'Post errors info'	=>	'The following errors need to be corrected before the message can be posted:',
'Post preview'		=>	'Post preview',
'Guest name'		=>	'Name', // For guests (instead of Username)
'Post redirect'		=>	'Post entered. Redirecting …',
'Post a reply'		=>	'Post a reply',
'Post new topic'	=>	'Post new topic',
'Hide smilies'		=>	'Never show smilies as icons for this post',
'Subscribe'			=>	'Subscribe to this topic',
'Stay subscribed'	=>	'Stay subscribed to this topic',
'Topic review'		=>	'Topic review (newest first)',
'Flood start'		=>	'At least',
'flood end'			=>	'seconds have to pass between posts. Please wait a little while and try posting again.',
'Preview'			=>	'Preview', // submit button to preview message

// Edit post
'Edit post legend'	=>	'Edit the post and submit changes',
'Silent edit'		=>	'Silent edit (don\'t display "Edited by ..." in topic view)',
'Edit post'			=>	'Edit post',
'Edit redirect'		=>	'Post updated. Redirecting …'

);

==> fluxbb-1.5.0p0.tgz: fluxbb/lang/English/post.php <==
<?php

// Language definitions used in post.php and edit.php
$lang_post = array(

// Post validation stuff (many are similiar to those in edit.php)
'No subject'		=>	'Topics must contain a subject.',
'No subject after censoring'	=>	'Topics must contain a subject. After applying censoring filters, your subject was empty.',
'Too long subject'	=>	'Subjects cannot be longer than 70 characters.',
'No message'		=>	'You must enter a message.',
'No message after censoring'	=>	'You must enter a message. After applying censoring filters, your message was empty.',
'Too long message'	=>	'Posts cannot be longer than %s bytes.',
'All caps subject'	=>	'Subjects cannot contain only capital letters.',
'All caps message'	=>	'Posts cannot contain only capital letters.',
'Empty after strip'	=>	'It seems your post consisted of empty BBCodes only. It is possible that this happened because e.g. the innermost quote was discarded because of the maximum quote depth level.',

// Posting
'Post errors'		=>	'Post errors',
'Post errors info'	=>	'The following errors need to be corrected before the message can be posted:',
'Post preview'		=>	'Post preview',
'Guest name'		=>	'Name', // For guests (instead of Username)
'Post redirect'		=>	'Post entered. Redirecting …',
'Post a reply'		=>	'Post a reply',
'Post new topic'	=>	'Post new topic',
'Hide smilies'		=>	'Never show smilies as icons for this post',
'Subscribe'			=>	'Subscribe to this topic',
'Stay subscribed'	=>	'Stay subscribed to this topic',
'Topic review'		=>	'Topic review (newest first)',
'Flood start'		=>	'At least',
'flood end'			=>	'seconds have to pass between posts. Please wait a little while and try posting again.',
'Preview'			=>	'Preview', // submit button to preview message

// Edit post
'Edit post legend'	=>	'Edit the post and submit changes',
'Silent edit'		=>	'Silent edit (don\'t display "Edited by ..." in topic view)',
'Edit post'			=>	'Edit post',
'Edit redirect'		=>	'Post updated. Redirecting …'

);
